@@ -359,14 +359,16 @@ class DragonGather(TaskScheduler):
             self.process_queue.put(ids)
             self.enqueued.append(ids)
             self.gui_set.append(dataset['code'])
+            for k, s in self.stations.items():
+                bprint(f"{k} : {s}")
 
     def load_dbdata(self, msg):
         bprint("="*10)
-        gprint(msg)
         print(len(msg), type(msg))
         rprint("="*10)
         for k, v in msg.items():
             self.db_data[k] = v
+            bprint(f"{k} : {v}")
 
     def msg_load_stations(self):
         get_lst = {'user': 'admin',
@@ -756,44 +758,6 @@ class DragonGather(TaskScheduler):
             ], kwargs
         return [ipt, ids, v, sta], kwargs
 
-    async def status_gather_task(self, ids, loop, wargs_list, **kwargs):
-        # List of stations asigned to cpu
-        # await asyncio.sleep(5)
-
-        # bprint("Wargs dict on status gather task %s" % wargs_list)
-        # Generate gather data over the list on same cpu
-
-        task_result = {}
-
-        bprint("Check on status task if assigned")
-        value = self.status_tasks[ids]
-        rprint(f"IDS {ids} -> {value}")
-        if self.status_tasks[ids]:
-            try:
-                wargs = [ids, loop, wargs_list]
-                result, kwargs = await self.gather_data(
-                    *wargs, **kwargs)
-                task_result.update({ids: result[2]})
-                wargs = result[2]
-                wargs_list = wargs
-                self.status_tasks[ids] = True
-            except Exception as e:
-                raise e
-        return [ids, loop, wargs_list], kwargs
-
-    async def gather_process(self, ipt, loop, ipt_wargs_dict, **kwargs):
-        result_dict = {}
-        ids_list = self.proc_tasks[ipt]
-        for ids in ids_list:
-            if ids not in ipt_wargs_dict.keys():
-                wargs = [None, None, None, None]
-                ipt_wargs_dict.update({ids: wargs})
-            wargs_dict = [ids, loop, ipt_wargs_dict[ids]]
-            result, kwargs = await self.status_gather_task(
-                *wargs_dict, **kwargs)
-            result_dict.update({ids: result[2]})
-        return [ipt, loop, result_dict], kwargs
-
     def set_pst(self, ids, args, kwargs):
         return [args[0], ids, *args[1:]], kwargs
 
@@ -805,4 +769,11 @@ class DragonGather(TaskScheduler):
                       ipt, "localhost@pineiden",
                       path=self.log_path/"engine")
         self.log_manager[ipt] = log
+        bprint(f"Init filelog on IPT {ipt}")
+        rprint(log)
         return [ipt, 1, (None, None, (None, None), None)], {"log": log}
+
+    def manage_tasks(self, ipt):
+        bprint(f"Init task process IPT {ipt}")
+        super().manage_task(ipt)
+        rprint(f"End manage tstk {ipt}")
