@@ -203,8 +203,10 @@ def start_datawork(env, conf="collector_example.json"):
             'bridge': bridge,
             'status_tasks': status_tasks,
             'assigned_tasks': assigned_tasks,
-            'rdb_address': tuple(map(data.get, ("RDB_SOURCE_HOST", "RDB_SOURCE_PORT"))),
-            'rdb_enu_address': tuple(map(data.get, ("RDB_ENU_HOST", "RDB_ENU_PORT"))),
+            'rdb_address': tuple(map(data.get, (
+                "RDB_SOURCE_HOST", "RDB_SOURCE_PORT"))),
+            'rdb_enu_address': tuple(map(data.get, (
+                "RDB_ENU_HOST", "RDB_ENU_PORT"))),
             'rdb_dbname': rdb_dbname,
             'chart': 'gnss_graph',
             'gui_set': gui_set,
@@ -368,14 +370,18 @@ def start_datawork(env, conf="collector_example.json"):
 
         tasks_list.append(assignator.new_process_task())
         bprint("Iniciando tareas")
-        asyncio.run()
+        loop.run_until_complete(asyncio.gather(*tasks_list))
 
 
 @click.command()
-@click.option("--name", default="datawork", show_default=True, help="Nombre de la instancia datawork a crear")
-@click.option("--env_vars/--no-env_vars", default=True, show_default=True,  type=bool, help="Para mostrar el nombre de las variables de ambiente")
-@click.option("--env/--no-env", default=True, show_default=True,  type=bool, required=True, help="Si obtener los datos de ambiente o cargarlos de un json o data entregada")
-@click.option("--conf", default="JSON FILE",  show_default=True, help="Archivo json con los parámetros de configuración")
+@click.option("--name", default="datawork", show_default=True,
+              help="Nombre de la instancia datawork a crear")
+@click.option("--env_vars/--no-env_vars", default=True, show_default=True,
+              type=bool, help="Para mostrar el nombre de las variables de ambiente")
+@click.option("--env/--no-env", default=True, show_default=True,
+              type=bool, required=True, help="Si obtener los datos de ambiente o cargarlos de un json o data entregada")
+@click.option("--conf", default="JSON FILE",  show_default=True,
+              help="Archivo json con los parámetros de configuración")
 def run_datawork(name, env_vars, env, conf):
     print("Iniciando servicio DATAWORK para %s" % name.upper())
     if env and env_vars:
